@@ -25,7 +25,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: prelude.c,v 1.1.1.1 1999/09/12 03:26:49 pjm Exp $
  */
 
 #include <stdio.h>
@@ -33,6 +33,8 @@
 #define L_DEFAULT_PARAMS stdout
 #define DL_DEFAULT_PARAMS stdout
 
+#include <nana-config.h>
+
 #include <nana.h>
 #include <now.h>
 #include <assert.h>
@@ -86,6 +88,7 @@ void __BSD_assert(char *f, int n, char *e) {
 
 /* cycles.h testing -- SHOULD only work on pentiums/cyrixs/... */
 /* See below for more code */
+#if HAVE_CYCLES
 volatile long long cycles_t;
 #include "../src/cycles.h"
 
