@@ -29,7 +29,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_buffer.c,v 1.2 1998/01/17 11:31:00 pjm Exp $
+ * Id: L_buffer.c,v 1.2 1998/01/17 11:31:00 pjm Exp 
  */
 
 #include <stdio.h>
@@ -158,10 +158,10 @@ void L_buffer_printf(L_BUFFER *b, const char *format, ...) {
 #elif HAVE_VSPRINTF == 1
   n = vsprintf(&buffer[0], format, ap);
 #else
-error We need either vsprintf or vsnprintf for this one;
-Perhaps you should install liberty or some other rational library;
-Under Solaris 2.5 it has been reported that our autoconf script
-fails to find vsprintf, if so define HAVE_VSPRINTF in your makefile;
+#error We need either vsprintf or vsnprintf for this one;
+#error Perhaps you should install liberty or some other rational library;
+#error Under Solaris 2.5 it has been reported that our autoconf script
+#error fails to find vsprintf, if so define HAVE_VSPRINTF in your makefile;
 #endif
 
   va_end(ap);
