@@ -26,7 +26,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_times.c,v 1.1.1.1 1997/11/23 11:45:50 pjm Exp $
+ * Id: L_times.c,v 1.1.1.1 1997/11/23 11:45:50 pjm Exp 
  */
 
 #include <L_times.h>
@@ -38,9 +38,10 @@ L_TIMES *L_times_create(unsigned long n) {
   L_TIMES *p = malloc(sizeof(L_TIMES));
   if(p != 0) {
     p->ncalls = 0;
+    p->freeslot = 0;
     p->maxsamples = n;
-    p->times = calloc(sizeof(NANA_TIME), n);
-    p->names = calloc(sizeof(char *), n);
+    p->times = calloc(n, sizeof(NANA_TIME));
+    p->names = calloc(n, sizeof(char *));
     p->wraparound = 1;
     if(p->times == 0 || p->names == 0) {
       return 0;
