@@ -27,10 +27,10 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: nanafilter.c,v 1.2 1998/06/10 06:58:55 pjm Exp $
+ * Id: nanafilter.c,v 1.2 1998/06/10 06:58:55 pjm Exp 
  */
 
-static const char rcs[] ="$Id: nanafilter.c,v 1.2 1998/06/10 06:58:55 pjm Exp $";
+static const char rcs[] ="Id: nanafilter.c,v 1.2 1998/06/10 06:58:55 pjm Exp ";
 
 #include <stdio.h>
 
